// src/Carousel.ts
import CarouselSlider from "@boxslider/slider/effects/Carousel";

// src/core.ts
var SafeBaseElement = typeof HTMLElement !== "undefined" ? HTMLElement : class {
};
var register = typeof customElements !== "undefined" ? (name, Element) => {
  if (customElements.get(name) === void 0) {
    customElements.define(name, Element);
  }
} : () => {
};

// src/Slider.ts
import BoxSlider, { defaultOptions } from "@boxslider/slider/BoxSlider";
var BOOLEAN_ATTRIBUTES = ["auto-scroll", "loop", "pause-on-hover", "swipe"];
var NUMERIC_ATTRIBUTES = [
  "speed",
  "start-index",
  "swipe-tolerance",
  "timeout"
];
var SLIDER_ATTRIBUTES = [...BOOLEAN_ATTRIBUTES, ...NUMERIC_ATTRIBUTES];
var Slider = class extends SafeBaseElement {
  #slider;
  #observer;
  #optionsCache = {};
  static observedAttributes = SLIDER_ATTRIBUTES;
  #getOrDefault(option) {
    return this.#optionsCache[option] ?? this.#slider?.getOption(option) ?? defaultOptions[option];
  }
  get slider() {
    return this.#slider;
  }
  get autoScroll() {
    return this.#getOrDefault("autoScroll");
  }
  set autoScroll(autoScroll) {
    if (this.slider) {
      if (autoScroll) {
        this.slider.play();
      } else {
        this.slider.pause();
      }
    } else {
      this.reset({ autoScroll });
    }
  }
  get loop() {
    return this.#getOrDefault("loop");
  }
  set loop(loop) {
    this.reset({ loop });
  }
  get pauseOnHover() {
    return this.#getOrDefault("pauseOnHover");
  }
  set pauseOnHover(pauseOnHover) {
    this.reset({ pauseOnHover });
  }
  get speed() {
    return this.#getOrDefault("speed");
  }
  set speed(speed) {
    this.reset({ speed });
  }
  get startIndex() {
    return this.#getOrDefault("startIndex");
  }
  set startIndex(startIndex) {
    this.reset({ startIndex });
  }
  get swipe() {
    return this.#getOrDefault("swipe");
  }
  set swipe(swipe) {
    this.reset({ swipe });
  }
  get swipeTolerance() {
    return this.#getOrDefault("swipeTolerance");
  }
  set swipeTolerance(swipeTolerance) {
    this.reset({ swipeTolerance });
  }
  get timeout() {
    return this.#getOrDefault("timeout");
  }
  set timeout(timeout) {
    this.reset({ timeout });
  }
  get options() {
    return {
      autoScroll: this.autoScroll,
      loop: this.loop,
      pauseOnHover: this.pauseOnHover,
      speed: this.speed,
      startIndex: this.startIndex,
      swipe: this.swipe,
      swipeTolerance: this.swipeTolerance,
      timeout: this.timeout
    };
  }
  constructor() {
    super();
    this.#observer = new MutationObserver((mutations) => {
      const needsReset = mutations.some(
        (mutation) => [...mutation.addedNodes, ...mutation.removedNodes].some(
          (node) => {
            return !(node instanceof HTMLElement && node.dataset.bsElement);
          }
        )
      );
      if (needsReset) {
        this.reset({ startIndex: this.slider?.activeIndex ?? 0 });
      }
    });
  }
  init(effect) {
    const slider = new BoxSlider(this, effect, this.#optionsCache);
    const events = [
      "after",
      "before",
      "destroy",
      "pause",
      "play",
      "reset"
    ];
    events.forEach(
      (ev) => slider.addEventListener(
        ev,
        (detail) => this.dispatchEvent(new CustomEvent(ev, { detail }))
      )
    );
    this.#slider = slider;
    this.#observer.observe(this, { childList: true });
    this.#optionsCache = {};
  }
  reset(options, effect) {
    if (this.slider) {
      const combinedOptions = { ...this.#optionsCache, ...options };
      this.slider?.reset(combinedOptions, effect);
      this.#optionsCache = {};
    } else {
      this.#optionsCache = { ...this.#optionsCache, ...options };
    }
  }
  attributeChangedCallback(name, _, value) {
    if (SLIDER_ATTRIBUTES.includes(name)) {
      const propName = name.replace(/-./g, (m) => m[1].toUpperCase());
      if (NUMERIC_ATTRIBUTES.includes(name)) {
        this[propName] = parseInt(value, 10);
      } else if (BOOLEAN_ATTRIBUTES.includes(name)) {
        this[propName] = value !== "false";
      }
    }
  }
  disconnectedCallback() {
    this.#observer.disconnect();
    this.slider?.destroy();
    this.#slider = void 0;
  }
};

// src/Carousel.ts
var Carousel = class extends Slider {
  static observedAttributes = [...SLIDER_ATTRIBUTES, "cover", "timing-function"];
  #timingFunction = null;
  #cover = false;
  get cover() {
    return this.#cover;
  }
  set cover(cover) {
    this.#cover = cover;
    this.reset(
      {},
      new CarouselSlider({
        cover,
        timingFunction: this.timingFunction
      })
    );
  }
  get timingFunction() {
    return this.#timingFunction ?? "ease-out";
  }
  set timingFunction(timingFunction) {
    this.#timingFunction = timingFunction;
    this.reset(
      {},
      new CarouselSlider({
        cover: this.cover,
        timingFunction
      })
    );
  }
  connectedCallback() {
    this.init(
      new CarouselSlider({
        cover: this.cover,
        timingFunction: this.timingFunction
      })
    );
  }
  attributeChangedCallback(name, _, value) {
    if (name === "timing-function") {
      this.timingFunction = value;
    } else if (name === "cover") {
      this.cover = value !== "false";
    } else {
      super.attributeChangedCallback(name, _, value);
    }
  }
};
register("bs-carousel", Carousel);
export {
  Carousel as default
};
