// src/core.ts
var SafeBaseElement = typeof HTMLElement !== "undefined" ? HTMLElement : class {
};
var register = typeof customElements !== "undefined" ? (name, Element) => {
  if (customElements.get(name) === void 0) {
    customElements.define(name, Element);
  }
} : () => {
};

// src/Slider.ts
import BoxSlider, { defaultOptions } from "@boxslider/slider/BoxSlider";
var BOOLEAN_ATTRIBUTES = ["auto-scroll", "loop", "pause-on-hover", "swipe"];
var NUMERIC_ATTRIBUTES = [
  "speed",
  "start-index",
  "swipe-tolerance",
  "timeout"
];
var SLIDER_ATTRIBUTES = [...BOOLEAN_ATTRIBUTES, ...NUMERIC_ATTRIBUTES];
var Slider = class extends SafeBaseElement {
  #slider;
  #observer;
  #optionsCache = {};
  static observedAttributes = SLIDER_ATTRIBUTES;
  #getOrDefault(option) {
    return this.#optionsCache[option] ?? this.#slider?.getOption(option) ?? defaultOptions[option];
  }
  get slider() {
    return this.#slider;
  }
  get autoScroll() {
    return this.#getOrDefault("autoScroll");
  }
  set autoScroll(autoScroll) {
    if (this.slider) {
      if (autoScroll) {
        this.slider.play();
      } else {
        this.slider.pause();
      }
    } else {
      this.reset({ autoScroll });
    }
  }
  get loop() {
    return this.#getOrDefault("loop");
  }
  set loop(loop) {
    this.reset({ loop });
  }
  get pauseOnHover() {
    return this.#getOrDefault("pauseOnHover");
  }
  set pauseOnHover(pauseOnHover) {
    this.reset({ pauseOnHover });
  }
  get speed() {
    return this.#getOrDefault("speed");
  }
  set speed(speed) {
    this.reset({ speed });
  }
  get startIndex() {
    return this.#getOrDefault("startIndex");
  }
  set startIndex(startIndex) {
    this.reset({ startIndex });
  }
  get swipe() {
    return this.#getOrDefault("swipe");
  }
  set swipe(swipe) {
    this.reset({ swipe });
  }
  get swipeTolerance() {
    return this.#getOrDefault("swipeTolerance");
  }
  set swipeTolerance(swipeTolerance) {
    this.reset({ swipeTolerance });
  }
  get timeout() {
    return this.#getOrDefault("timeout");
  }
  set timeout(timeout) {
    this.reset({ timeout });
  }
  get options() {
    return {
      autoScroll: this.autoScroll,
      loop: this.loop,
      pauseOnHover: this.pauseOnHover,
      speed: this.speed,
      startIndex: this.startIndex,
      swipe: this.swipe,
      swipeTolerance: this.swipeTolerance,
      timeout: this.timeout
    };
  }
  constructor() {
    super();
    this.#observer = new MutationObserver((mutations) => {
      const needsReset = mutations.some(
        (mutation) => [...mutation.addedNodes, ...mutation.removedNodes].some(
          (node) => {
            return !(node instanceof HTMLElement && node.dataset.bsElement);
          }
        )
      );
      if (needsReset) {
        this.reset({ startIndex: this.slider?.activeIndex ?? 0 });
      }
    });
  }
  init(effect) {
    const slider = new BoxSlider(this, effect, this.#optionsCache);
    const events = [
      "after",
      "before",
      "destroy",
      "pause",
      "play",
      "reset"
    ];
    events.forEach(
      (ev) => slider.addEventListener(
        ev,
        (detail) => this.dispatchEvent(new CustomEvent(ev, { detail }))
      )
    );
    this.#slider = slider;
    this.#observer.observe(this, { childList: true });
    this.#optionsCache = {};
  }
  reset(options, effect) {
    if (this.slider) {
      const combinedOptions = { ...this.#optionsCache, ...options };
      this.slider?.reset(combinedOptions, effect);
      this.#optionsCache = {};
    } else {
      this.#optionsCache = { ...this.#optionsCache, ...options };
    }
  }
  attributeChangedCallback(name, _, value) {
    if (SLIDER_ATTRIBUTES.includes(name)) {
      const propName = name.replace(/-./g, (m) => m[1].toUpperCase());
      if (NUMERIC_ATTRIBUTES.includes(name)) {
        this[propName] = parseInt(value, 10);
      } else if (BOOLEAN_ATTRIBUTES.includes(name)) {
        this[propName] = value !== "false";
      }
    }
  }
  disconnectedCallback() {
    this.#observer.disconnect();
    this.slider?.destroy();
    this.#slider = void 0;
  }
};

// src/SliderControls/styles.ts
var styles_default = `
:host {
  --button-bar-gap: var(--bs-button-bar-gap, 0.5rem);
  --index-btn-color: var(
    --bs-index-btn-color,
    light-dark(rgb(0 0 0 / 40%), rgb(255 255 255 / 20%))
  );
  --index-btn-active-color: var(
    --bs-index-btn-active-color,
    light-dark(rgb(0 0 0 / 100%), rgb(255 255 255 / 80%))
  );
  --index-btn-size: var(--bs-index-btn-size, 1rem);
  --btn-background-color: var(
    --bs-btn-background-color,
    light-dark(rgb(0 0 0 / 40%), rgb(255 255 255 / 20%))
  );
  --btn-border-radius: var(--bs-btn-border-radius, 9999px);
  --btn-size: var(--bs-btn-size, 2rem);
  --next-icon: var(
    --bs-next-icon,
    url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="white" class="bi bi-chevron-right" viewBox="0 0 16 16"> <path fill-rule="evenodd" d="M4.646 1.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708L10.293 8 4.646 2.354a.5.5 0 0 1 0-.708"/></svg>')
  );
  --prev-icon: var(
    --bs-prev-icon,
    url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="white" class="bi bi-chevron-left" viewBox="0 0 16 16"> <path fill-rule="evenodd" d="M11.354 1.646a.5.5 0 0 1 0 .708L5.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0"/></svg>')
  );
  --play-icon: var(
    --bs-play-icon,
    url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="white" class="bi bi-play" viewBox="0 0 16 16"> <path d="M10.804 8 5 4.633v6.734zm.792-.696a.802.802 0 0 1 0 1.392l-6.363 3.692C4.713 12.69 4 12.345 4 11.692V4.308c0-.653.713-.998 1.233-.696z"/></svg>')
  );
  --pause-icon: var(
    --bs-pause-icon,
    url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="white" class="bi bi-pause" viewBox="0 0 16 16"> <path d="M6 3.5a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-1 0V4a.5.5 0 0 1 .5-.5m4 0a.5.5 0 0 1 .5.5v8a.5.5 0 0 1-1 0V4a.5.5 0 0 1 .5-.5"/></svg>')
  );

  display: block;
}

#container {
  display: grid;
  gap: var(--button-bar-gap);
  grid-template:
    'slider slider slider' auto
    'play index nav' 1fr / auto;
}

#slider-container {
  grid-area: slider;
}

#controls-container {
  grid-area: nav;
  justify-self: right;
}

#play-btn-container {
  grid-area: play;
  justify-self: left;
}

.btn {
  background-color: var(--btn-background-color);
  border: none;
  border-radius: var(--btn-border-radius);
  cursor: pointer;
  height: var(--btn-size);
  overflow: hidden;
  position: relative;
  transition: background-color 200ms;
  width: var(--btn-size);
}

.btn::before {
  background: no-repeat center;
  box-sizing: inherit;
  content: '';
  inset: 0;
  position: absolute;
}

#prev-btn::before {
  background-image: var(--prev-icon);
}

#next-btn::before {
  background-image: var(--next-icon);
}

#play-btn::before {
  background-image: var(--play-icon);
}

#play-btn[part~='pause']::before {
  background-image: var(--pause-icon);
}

#index-container {
  align-items: center;
  display: flex;
  gap: 0.5rem;
  grid-area: index;
  justify-self: center;
}

.index-btn {
  background-color: var(--index-btn-color);
  border: none;
  border-radius: 999px;
  cursor: pointer;
  height: var(--index-btn-size);
  transition: background-color 400ms;
  width: var(--index-btn-size);

  &[part~='active'], &[part~='active']:hover {
    background-color: var(--index-btn-active-color);
  }
}

@media (hover: hover) {
  :host {
    --index-btn-hover-color: var(
      --bs-index-btn-hover-color,
      light-dark(rgb(0 0 0 / 60%), rgb(255 255 255 / 40%))
    );
    --btn-hover-background-color: var(
      --bs-btn-hover-background-color,
      light-dark(rgb(0 0 0 / 60%), rgb(255 255 255 / 40%))
    );
  }

  .index-btn:hover {
    background-color: var(--index-btn-hover-color);
  }

  .btn:hover {
    background-color: var(--btn-hover-background-color);
  }
}
`;

// src/SliderControls/SliderControls.ts
var template;
if (typeof document !== "undefined") {
  template = document.createElement("template");
  template.innerHTML = `
<div part="container" id="container">
  <div part="slider-container" id="slider-container">
    <slot id="slider"></slot>
  </div>

  <div part="play-btn-container" id="play-btn-container">
    <slot name="play-btn">
      <button part="btn play-btn" id="play-btn" class="btn"></button>
    </slot>
  </div>

  <div part="controls-container" id="controls-container">
    <slot name="prev-btn">
      <button part="prev-btn btn" id="prev-btn" class="btn"></button>
    </slot>
    <slot name="next-btn">
      <button part="next-btn btn" id="next-btn" class="btn"></button>
    </slot>
  </div>

  <div part="index-container" id="index-container" role="group">
    <slot name="index"></slot>
  </div>
</div>
`;
}
var SliderControls = class extends SafeBaseElement {
  #sliderElement;
  #mutationObserver;
  #hasBeenInteractedWith = false;
  #sliderEventListeners = {};
  constructor() {
    super();
    this.#mutationObserver = new MutationObserver((mutations) => {
      const hasNewSlider = mutations.some((mutation) => {
        Array.from(mutation.addedNodes).some((node) => node instanceof Slider);
      });
      if (hasNewSlider) {
        this.#init();
      }
    });
  }
  connectedCallback() {
    const shadow = this.attachShadow({ mode: "open" });
    if (!this.hasAttribute("unstyled") || this.getAttribute("unstyled") === "false") {
      const style = document.createElement("style");
      style.appendChild(document.createTextNode(styles_default));
      shadow.appendChild(style);
    }
    shadow.appendChild(template.content.cloneNode(true));
    const sliderSlot = shadow.querySelector("#slider");
    if (!this.hasAttribute("aria-roledescription")) {
      this.setAttribute("aria-roledescription", "carousel");
    }
    if (!this.hasAttribute("role")) {
      this.setAttribute("role", "region");
    }
    this.#initializeControl(
      shadow.querySelector('slot[name="prev-btn"]'),
      () => this.#sliderElement?.slider?.prev(),
      { "aria-label": this.#prevBtnLabel() }
    );
    this.#initializeControl(
      shadow.querySelector('slot[name="next-btn"]'),
      () => this.#sliderElement?.slider?.next(),
      { "aria-label": this.#nextBtnLabel() }
    );
    this.#initPlayBtnSlot();
    this.#initIndexSlot();
    sliderSlot?.addEventListener("slotchange", () => this.#init());
  }
  #init() {
    this.#mutationObserver.disconnect();
    const sliderSlotRoot = this.shadowRoot?.querySelector("#slider")?.assignedElements()[0];
    if (!sliderSlotRoot) {
      return;
    }
    const isSliderElement = !!sliderSlotRoot.slider;
    if (isSliderElement) {
      this.#sliderElement = sliderSlotRoot;
    } else {
      this.#mutationObserver.observe(sliderSlotRoot, {
        subtree: true,
        childList: true
      });
      let sliderElement;
      for (const childEl of sliderSlotRoot.querySelectorAll(
        "*"
      )) {
        if (childEl.slider) {
          sliderElement = childEl;
          break;
        }
      }
      if (!sliderElement) {
        throw new Error("No slider element found in default slot");
      }
      this.#sliderElement = sliderElement;
    }
    if (this.#sliderElement.slider) {
      this.shadowRoot?.querySelectorAll('[part~="btn"]').forEach((btn) => {
        btn.setAttribute("aria-controls", "slider");
      });
      this.#setPlayBtnState();
      if (this.#sliderEventListeners.play) {
        this.#sliderElement.removeEventListener(
          "play",
          this.#sliderEventListeners.play
        );
      }
      if (this.#sliderEventListeners.reset) {
        this.#sliderElement.removeEventListener(
          "reset",
          this.#sliderEventListeners.reset
        );
      }
      if (this.#sliderEventListeners.pause) {
        this.#sliderElement.removeEventListener(
          "pause",
          this.#sliderEventListeners.pause
        );
      }
      this.#sliderEventListeners.play = () => this.#setPlayBtnState();
      this.#sliderElement.addEventListener(
        "play",
        this.#sliderEventListeners.play
      );
      this.#sliderEventListeners.pause = () => this.#setPlayBtnState();
      this.#sliderElement.addEventListener(
        "pause",
        this.#sliderEventListeners.pause
      );
      this.#sliderEventListeners.reset = () => this.#init();
      this.#sliderElement.addEventListener(
        "reset",
        this.#sliderEventListeners.reset
      );
      this.#addIndexPips();
      this.#sliderElement.addEventListener(
        "before",
        ({ detail: { currentIndex, nextIndex } }) => {
          this.#setIndexPipState(currentIndex, nextIndex);
        }
      );
    }
  }
  #initializeControl(slot, clickHandler, attributes = {}) {
    const defaultButton = slot.querySelector(".btn");
    if (defaultButton) {
      for (const [key, value] of Object.entries(attributes)) {
        defaultButton.setAttribute(key, value);
      }
    }
    slot.addEventListener("click", (ev) => {
      this.#hasBeenInteractedWith = true;
      this.#sliderElement.autoScroll = false;
      clickHandler(ev);
    });
    slot.addEventListener("focusin", () => {
      if (!this.#hasBeenInteractedWith) {
        this.#sliderElement.autoScroll = false;
      }
    });
  }
  #initIndexSlot() {
    const indexSlot = this.shadowRoot?.querySelector('slot[name="index"]');
    if (indexSlot) {
      indexSlot.setAttribute("aria-label", this.#indexSlotLabel());
      indexSlot?.addEventListener("click", (ev) => {
        const container = indexSlot.assignedElements()[0] ?? indexSlot;
        if (container) {
          const index = Array.from(
            container.querySelectorAll("button")
          ).indexOf(ev.target);
          if (index > -1) {
            this.#hasBeenInteractedWith = true;
            if (this.#sliderElement) {
              this.#sliderElement.autoScroll = false;
              this.#sliderElement.slider?.skipTo(index);
            }
          }
        }
      });
      indexSlot?.addEventListener("slotchange", () => {
        const container = indexSlot.assignedElements()[0];
        if (container) {
          const buttons = container.querySelectorAll("button");
          const slider = this.#sliderElement?.slider;
          if (slider && buttons) {
            buttons.forEach((btn, index) => {
              btn.setAttribute(
                "aria-disabled",
                index === slider.activeIndex ? "true" : "false"
              );
            });
          }
        }
      });
    }
  }
  #addIndexPips() {
    const indexSlot = this.shadowRoot?.querySelector('slot[name="index"]');
    if (indexSlot) {
      this.#clearIndexPips();
      const slideCount = this.#sliderElement?.slider?.length ?? 0;
      if (slideCount > 1 && !this.hasAttribute("disable-index")) {
        const frag = document.createDocumentFragment();
        const labelTemplate = this.getAttribute("index-btn-label") ?? "View slide %d";
        for (let i = 0; i < slideCount; i++) {
          const btn = document.createElement("button");
          const isActive = i === this.#sliderElement.slider.activeIndex;
          const label = labelTemplate.replace(/%d/g, `${i + 1}`);
          btn.setAttribute("aria-disabled", isActive ? "true" : "false");
          btn.setAttribute("aria-label", label);
          btn.setAttribute("aria-controls", "slider");
          btn.setAttribute("class", "index-btn");
          btn.setAttribute("part", isActive ? "index-btn active" : "index-btn");
          btn.setAttribute("type", "button");
          frag.appendChild(btn);
        }
        indexSlot?.appendChild(frag);
      }
    }
  }
  #setIndexPipState(currentIndex, nextIndex) {
    const indexSlot = this.shadowRoot?.querySelector('slot[name="index"]');
    if (indexSlot) {
      const container = indexSlot?.assignedElements()[0] ?? indexSlot;
      const buttons = container?.querySelectorAll("button");
      const currentBtn = buttons?.item(currentIndex);
      const nextBtn = buttons?.item(nextIndex ?? -1);
      if (currentBtn) {
        currentBtn.setAttribute("aria-disabled", "false");
        if (currentBtn.hasAttribute("part")) {
          currentBtn.setAttribute("part", "index-btn");
        }
      }
      if (nextBtn) {
        nextBtn.setAttribute("aria-disabled", "true");
        if (nextBtn.hasAttribute("part")) {
          nextBtn.setAttribute("part", "index-btn active");
        }
      }
    }
  }
  #clearIndexPips() {
    const indexSlot = this.shadowRoot?.querySelector('slot[name="index"]');
    if (indexSlot) {
      const assignedElements = indexSlot?.assignedElements() ?? [];
      indexSlot?.querySelectorAll("button").forEach((btn) => {
        if (!assignedElements.includes(btn)) {
          indexSlot.removeChild(btn);
        }
      });
    }
  }
  #initPlayBtnSlot() {
    const slot = this.shadowRoot?.querySelector(
      'slot[name="play-btn"]'
    );
    if (slot) {
      slot.addEventListener("slotchange", () => {
        this.#setPlayBtnState();
      });
      slot.addEventListener("click", () => {
        this.#hasBeenInteractedWith = true;
        if (this.#sliderElement) {
          this.#sliderElement.autoScroll = !this.#sliderElement.autoScroll;
        }
      });
    }
  }
  #setPlayBtnState() {
    const slot = this.shadowRoot?.querySelector(
      'slot[name="play-btn"]'
    );
    if (slot) {
      const button = slot.assignedElements()[0] ?? slot.querySelector(".btn");
      const isPlaying = this.#sliderElement.autoScroll;
      button.setAttribute(
        "aria-label",
        isPlaying ? this.#pauseButtonLabel() : this.#playButtonLabel()
      );
      button?.setAttribute(
        "part",
        isPlaying ? "btn play-btn pause" : "btn play-btn"
      );
    }
  }
  #indexSlotLabel() {
    return this.getAttribute("index-label") ?? "Select a slide";
  }
  #nextBtnLabel() {
    return this.getAttribute("next-btn-label") ?? "Next";
  }
  #prevBtnLabel() {
    return this.getAttribute("prev-btn-label") ?? "Previous";
  }
  #playButtonLabel() {
    return this.getAttribute("play-btn-label") ?? "Start slide auto scroll";
  }
  #pauseButtonLabel() {
    return this.getAttribute("pause-btn-label") ?? "Stop slide auto scroll";
  }
};
register("bs-slider-controls", SliderControls);
export {
  SliderControls as default
};
